@@ -42,6 +42,15 @@ setGeneric("as.markdown", function(.Object, ...) standardGeneric("as.markdown"))
 .as.markdown <- function(.Object, corpus, meta = NULL, cpos = FALSE, cutoff = NULL, ...){
   corpusEncoding <- registry_get_encoding(corpus)
   
+  if (is.null(get_template(corpus))){
+    warning(
+      sprintf(
+        "No template available for corpus '%s', it will not be possible to format fulltext output.",
+        corpus
+      )
+    )
+  }
+  
   # generate metainformation
   documentStruc <- cl_cpos2struc(
     corpus = corpus,
@@ -122,7 +131,7 @@ setMethod(
     .message("as.markdown", verbose = verbose)
     # ensure that template requested is available
     if (is.null(template)){
-      stop("template needed for formatting a partition of corpus ", .Object@corpus , " is missing, use set_template()")
+      stop("template needed for formatting a partition of corpus.")
     }
     if (is.null(template[["paragraphs"]])){
       .message("generating paragraphs (no template)", verbose = verbose)
@@ -159,10 +168,11 @@ setMethod("as.markdown", "plpr_partition", function(.Object, meta = NULL, templa
 #' @rdname as.markdown
 setMethod("as.markdown", "plpr_subcorpus", function(.Object, meta = NULL, template = get_template(.Object), cpos = FALSE, interjections = TRUE, cutoff = NULL, ...){
   # in the function call, meta is actually not needed, required by the calling function
+  if (is.null(template)) warning("No template available, formatting fulltext output is likely to fail.")
   if (is.null(meta)) meta <- template[["metadata"]]
   if (interjections){
-    maxNoStrucs <- .Object@strucs[length(.Object@strucs)] - .Object@strucs[1] + 1L
-    if (maxNoStrucs != length(.Object@strucs)){
+    strucs_range <- .Object@strucs[length(.Object@strucs)] - .Object@strucs[1] + 1L
+    if (strucs_range != length(.Object@strucs)){
       .Object@strucs <- .Object@strucs[1]:.Object@strucs[length(.Object@strucs)]
       # fill regions matrix to include interjections
       .Object@cpos <- RcppCWB::get_region_matrix(
@@ -173,24 +183,24 @@ setMethod("as.markdown", "plpr_subcorpus", function(.Object, meta = NULL, templa
     }
   }
   
-  # detect where a change of metainformation occurs
-  metadata <- as.matrix(s_attributes(.Object, s_attribute = meta)) # somewhat slow
+  # detect where a change of metainformation occurs (somewhat slow)
+  metadata <- as.matrix(s_attributes(.Object, s_attribute = meta, unique = FALSE)) 
   if (length(.Object@strucs) > 1L){
-    metaChange <- sapply(2L:nrow(metadata), function(i) !all(metadata[i,] == metadata[i - 1L,]))
-    metaChange <- c(TRUE, metaChange)
+    meta_change <- sapply(2L:nrow(metadata), function(i) !all(metadata[i,] == metadata[i - 1L,]))
+    meta_change <- c(TRUE, meta_change)
   } else {
-    metaChange <- TRUE
+    meta_change <- TRUE
   }
   
   type <- cl_struc2str(corpus = .Object@corpus, s_attribute = template[["speech"]][["sAttribute"]], struc = .Object@strucs, registry = registry())
   
   if (is.numeric(cutoff)){
-    beyondCutoff <- which(cumsum(.Object@cpos[,2] - .Object@cpos[,1]) > cutoff)
-    if (length(beyondCutoff) > 0){
-      threshold <- min(beyondCutoff)
-      if (threshold > 1){
-        metadata <- metadata[1:threshold,]
-        .Object@cpos <- .Object@cpos[1:threshold,]
+    beyond_cutoff <- which(cumsum(.Object@cpos[,2] - .Object@cpos[,1]) > cutoff)
+    if (length(beyond_cutoff) > 0L){
+      threshold <- min(beyond_cutoff)
+      if (threshold > 1L){
+        metadata <- metadata[1L:threshold,]
+        .Object@cpos <- .Object@cpos[1L:threshold,]
       }
     }
   }
@@ -199,7 +209,7 @@ setMethod("as.markdown", "plpr_subcorpus", function(.Object, meta = NULL, templa
     1L:nrow(metadata),
     function(i) {
       meta <- ""
-      if (metaChange[i] == TRUE) { 
+      if (meta_change[i] == TRUE) { 
         meta <- paste(metadata[i,], collapse=" | ", sep="")
         meta <- paste(
           template[["document"]][["format"]][1],
@@ -215,14 +225,14 @@ setMethod("as.markdown", "plpr_subcorpus", function(.Object, meta = NULL, templa
         cpos = cpos
       )
     tokens <- .tagTokens(tokens)
-    plainText <- paste(tokens, collapse = " ")
-    plainText <- paste(
+    plaintext <- paste(tokens, collapse = " ")
+    plaintext <- paste(
       template[["speech"]][["format"]][[type[i]]][1],
-      plainText,
+      plaintext,
       template[["speech"]][["format"]][[type[i]]][1],
       sep = ""
       )
-    paste(meta, plainText)
+    paste(meta, plaintext)
   })
   markdown <- paste(markdown, collapse = "\n\n")
   markdown <- gsub("(.)\\s([,.:!?])", "\\1\\2", markdown)
